import sys

from django.apps import apps
from django.core.management.base import BaseCommand, CommandError
from django.utils.module_loading import import_string

from ...exporting import read_requests, response_writer
from ...strategies import Exportable


class Command(BaseCommand):
    help = "Dump the data generated by a given strategy."

    def handle(self, **options):
        for request in read_requests(sys.stdin.buffer):
            with response_writer(sys.stdout.buffer) as output:
                self.handle_request(request, output)

    def handle_request(self, request, output):
        app_name, model_name = request.app_model_label.split(".")
        app_config = apps.get_app_config(app_name)
        model = app_config.get_model(model_name)

        strategy = import_string(request.strategy_class)(
            **request.strategy_kwargs
        )

        if not isinstance(strategy, Exportable):
            raise CommandError("Strategy not locally exportable")

        strategy.export_local(request.database, model, output)
